'''
    block: [[x1, y1],[x2, y2]] with a radius of 10
    ball: [X, Y, Radius]
    eli: 0/1 indicates whether the body can be eliminated
    dynamic: 0/1 indicates whether the body can move under Newtonian laws

    When designing, be careful about the following points:
    1. the original point is at the left-top corner of the screen
    2. when specifying the vertices of blocks, try to write from smaller numbers to larger numbers
    3. the number of blocks equals to the number of eli and the number of dynamic.
'''

PARAS = {
    # Basic 10
    'support':
        {'block': [[[200., 400.], [300., 400.]],
                   [[200., 500.], [300., 500.]]],
         'ball': [[250., 340., 20.]],
         'eli': [1, 1, 0],
         'dynamic': [0, 0, 1],
         },
    'hinder':
        {'block': [[[200., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]]],
         'ball': [[250., 100., 20.]],
         'eli': [0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 1],
         },
    'direction':
        {'block': [[[200., 400.], [400., 400.]],
                   [[200., 300.], [200., 380.]],
                   [[400., 300.], [400., 380.]],
                   [[200., 200.], [280., 250.]],
                   [[320., 250.], [400., 200.]]],
         'ball': [[300., 200., 20.]],
         'eli': [0, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 1],
         },
    'hole':
        {'block': [[[100., 400.], [250., 400.]],
                   [[350., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]],
                   [[250., 100.], [250., 150.]],
                   ],
         'ball': [[220., 120., 20.]],
         'eli': [0, 0, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1],
         },
    'fill':
        {'block': [[[100., 420.], [400., 420.]],
                   [[100., 400.], [250., 400.]],
                   [[350., 400.], [400., 400.]],
                   [[270., 200.], [330., 200.]],
                   [[270., 180.], [330., 180.]],
                   [[100., 150.], [180., 200.]],
                   [[150., 100.], [150., 150.]],
                   ],
         'ball': [[120., 120., 20.]],
         'eli': [0, 0, 0, 1, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 1, 0, 0, 1],
         },
    'seesaw':
        {'block': [[[200., 420.], [500., 420.]],
                   [[200., 400.], [200., 300.]],
                   [[500., 400.], [500., 300.]],
                   [[240., 320.], [470., 250.]],
                   [[280., 340.], [290., 340.]],
                   [[450., 330.], [460., 310.]],
                   ],
         'ball': [[400., 200., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 1, 0, 0, 1],
         },
    'angle':
        {'block': [[[100., 400.], [400., 400.]],
                   [[200., 350.], [210., 350.]],
                   [[200., 300.], [210., 300.]],
                   [[480., 400.], [550., 400.]],
                   [[390., 350.], [400., 350.]],
                   [[390., 300.], [400., 300.]],
                   [[100., 380.], [100., 360.]],
                   [[550., 380.], [550., 360.]],
                   [[200., 280.], [400., 280.]],
                   ],
         'ball': [[300., 250., 20.]],
         'eli': [0, 1, 1, 0, 1, 1, 0, 0, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
         },
    'impulse':
        {'block': [[[150., 300.], [250., 380.]],
                   [[270., 400.], [400., 400.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[200., 130.], [220., 130.]],
                   ],
         'ball': [[360., 170., 20.]],
         'eli': [0, 0, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 1],
         },
    'pendulum':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   ],
         'ball': [[360., 170., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1],
         'joint': [[5, 6]],
         },
    'spring':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[300., 200.], [420., 200.]],
                   [[180., 100.], [240., 100.]],
                   ],
         'ball': [[400., 170., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1],
         'spring': [[5, 6]],
         },
    # Compositional 10
    'support_hinder':
        {'block': [[[240., 130.], [260., 130.]],
                   [[200., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]]],
         'ball': [[250., 100., 20.]],
         'eli': [1, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 1],
         },
    'support_direction':
        {'block': [[[290., 130.], [310., 130.]],
                   [[200., 400.], [400., 400.]],
                   [[200., 300.], [200., 380.]],
                   [[400., 300.], [400., 380.]],
                   [[200., 200.], [280., 250.]],
                   [[320., 250.], [400., 200.]]],
         'ball': [[300., 100., 20.]],
         'eli': [1, 0, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1],
         },
    'support_hole':
        {'block': [[[210., 120.], [230., 120.]],
                   [[100., 400.], [250., 400.]],
                   [[350., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]],
                   [[250., 100.], [250., 150.]],
                   ],
         'ball': [[220., 90., 20.]],
         'eli': [1, 0, 0, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 1],
         },
    'more_step_hole':
        {'block': [[[100., 400.], [250., 400.]],
                   [[350., 400.], [500., 400.]],
                   [[100., 300.], [100., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 100.], [250., 130.]],
                   [[250., 50.], [250., 100.]],
                   [[280., 230.], [350., 200.]],
                   [[200., 270.], [400., 350.]],
                   ],
         'ball': [[220., 70., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 0, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1],
         },
    'hinder_fill':
        {'block': [[[200., 520.], [500., 520.]],
                   [[200., 500.], [350., 500.]],
                   [[450., 500.], [500., 500.]],
                   [[370., 400.], [430., 400.]],
                   [[370., 380.], [430., 380.]],
                   [[200., 350.], [280., 400.]],
                   [[250., 300.], [250., 350.]],
                   [[10., 250.], [160., 250.]],
                   [[160., 230.], [160., 200.]],
                   [[10., 50.], [50., 100.]],
                   [[70., 40.], [70., 70.]],
                   ],
         'ball': [[30., 20., 20.]],
         'eli': [0, 0, 0, 1, 0, 1, 1, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1],
         },
    'impulse_spring':
        {'block': [[[150., 300.], [250., 380.]],
                   [[270., 400.], [400., 400.]],
                   [[300., 200.], [500., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[200., 130.], [220., 130.]],
                   ],
         'ball': [[450., 170., 20.]],
         'eli': [0, 0, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 1],
         'spring': [[4, 5]],
         },
    'impulse_pendulum':
        {'block': [[[150., 300.], [250., 380.]],
                   [[270., 400.], [400., 400.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[200., 130.], [220., 130.]],
                   ],
         'ball': [[360., 170., 20.]],
         'eli': [0, 0, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 1],
         'joint': [[4, 5]],
         },
    'activated_pendulum':
        {'block': [[[270., 100.], [280., 100.]],
                   [[320., 100.], [330., 100.]],
                   [[270., 80.], [280., 80.]],
                   [[320., 80.], [330., 80.]],
                   [[290., 270.], [310., 270.]],
                   [[10., 400.], [400., 400.]],
                   [[10., 100.], [10., 380.]],
                   [[420., 400.], [500., 320.]],
                   ],
         'ball': [[300., 200., 20.]],
         'eli': [1, 1, 0, 0, 1, 0, 0, 0, 0],
         'dynamic': [0, 0, 1, 1, 0, 0, 0, 0, 1],
         'joint': [[4, 8]],
         },
    'spring_flick':
        {'block': [[[100., 420.], [590., 420.]],
                   [[400., 400.], [590., 400.]],
                   [[10., 200.], [10., 400.]],
                   [[580., 380.], [590., 380.]],
                   [[70., 370.], [150., 370.]],
                   [[100., 150.], [180., 200.]],
                   ],
         'ball': [[100., 340., 20.]],
         'eli': [0, 0, 1, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 1, 0, 0, 1],
         'spring': [[5, 3]],
         },
    'seesaw_angle':
        {'block': [[[200., 420.], [500., 420.]],
                   [[200., 400.], [200., 300.]],
                   [[500., 400.], [500., 300.]],
                   [[240., 250.], [470., 250.]],
                   [[280., 340.], [290., 340.]],
                   [[280., 310.], [290., 310.]],
                   [[450., 310.], [460., 310.]],
                   ],
         'ball': [[400., 200., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 1, 0, 0, 0, 1],
         },
    # Noisy 10
    'noisy_support':
        {'block': [[[200., 400.], [300., 400.]],
                   [[200., 500.], [300., 500.]],
                   [[400., 400.], [500., 400.]],
                   [[400., 500.], [500., 500.]],
                   ],
         'ball': [[450., 340., 20.]],
         'eli': [1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 1],
         },
    'noisy_hinder':
        {'block': [[[200., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]],
                   [[450., 200.], [450., 280.]],
                   [[500., 200.], [500., 280.]]],
         'ball': [[250., 100., 20.]],
         'eli': [0, 1, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1],
         },
    'noisy_direction':
        {'block': [[[200., 400.], [400., 400.]],
                   [[200., 300.], [200., 380.]],
                   [[400., 300.], [400., 380.]],
                   [[200., 200.], [280., 250.]],
                   [[320., 250.], [400., 200.]],
                   [[200., 100.], [280., 150.]],
                   [[320., 150.], [400., 100.]]],
         'ball': [[300., 200., 20.]],
         'eli': [0, 1, 1, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 1],
         },
    'noisy_hole':
        {'block': [[[100., 400.], [250., 400.]],
                   [[350., 400.], [500., 400.]],
                   [[450., 300.], [450., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 150.], [300., 200.]],
                   [[250., 100.], [250., 150.]],
                   [[250., 200.], [250., 250.]],
                   ],
         'ball': [[220., 120., 20.]],
         'eli': [0, 0, 1, 1, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 1],
         },
    'noisy_fill':
        {'block': [[[100., 420.], [400., 420.]],
                   [[100., 400.], [250., 400.]],
                   [[350., 400.], [400., 400.]],
                   [[270., 200.], [330., 200.]],
                   [[270., 180.], [330., 180.]],
                   [[100., 150.], [180., 200.]],
                   [[150., 100.], [150., 150.]],
                   [[350., 200.], [410., 200.]],
                   [[350., 180.], [410., 180.]],
                   ],
         'ball': [[120., 120., 20.]],
         'eli': [0, 0, 0, 1, 0, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 0, 0, 0, 1, 1],
         },
    'noisy_seesaw':
        {'block': [[[200., 420.], [500., 420.]],
                   [[200., 400.], [200., 300.]],
                   [[500., 400.], [500., 300.]],
                   [[250., 320.], [470., 250.]],
                   [[280., 340.], [290., 340.]],
                   [[450., 330.], [460., 310.]],
                   [[320., 350.], [330., 350.]],
                   ],
         'ball': [[400., 200., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 1, 0, 0, 0, 1],
         },
    'noisy_angle':
        {'block': [[[100., 400.], [400., 400.]],
                   [[200., 350.], [210., 350.]],
                   [[200., 300.], [210., 300.]],
                   [[480., 400.], [550., 400.]],
                   [[390., 350.], [400., 350.]],
                   [[390., 300.], [400., 300.]],
                   [[100., 380.], [100., 360.]],
                   [[550., 380.], [550., 360.]],
                   [[200., 280.], [400., 280.]],
                   [[300., 350.], [310., 350.]],
                   [[300., 300.], [310., 300.]],
                   ],
         'ball': [[300., 250., 20.]],
         'eli': [0, 1, 1, 0, 1, 1, 0, 0, 0, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1],
         },
    'noisy_impulse':
        {'block': [[[150., 300.], [250., 380.]],
                   [[270., 400.], [400., 400.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[200., 130.], [220., 130.]],
                   [[280., 200.], [320., 200.]],
                   [[290., 180.], [310., 180.]],
                   ],
         'ball': [[360., 170., 20.]],
         'eli': [0, 0, 1, 1, 0, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 0, 1, 1],
         },
    # 'noisy_lever':
    #     {'block': [[[290., 420.], [310., 420.]],
    #                [[200., 400.], [400., 400.]],
    #                [[280., 200.], [320., 200.]],
    #                [[380., 200.], [420., 200.]],
    #                [[290., 180.], [310., 180.]],
    #                [[390., 180.], [410., 180.]],
    #                [[100., 200.], [140., 200.]],
    #                [[110., 180.], [130., 180.]],
    #                ],
    #      'ball': [[250., 370., 20.],
    #               [350., 370., 20.]],
    #      'eli': [0, 0, 1, 1, 0, 0, 1, 0, 0, 0],
    #      'dynamic': [0, 1, 0, 0, 1, 1, 0, 1, 1, 1],
    #      },
    'noisy_pendulum':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[180., 170.], [240., 170.]],
                   ],
         'ball': [[360., 170., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 1],
         'joint': [[6, 7]],
         },
    'noisy_spring':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[300., 200.], [420., 200.]],
                   [[180., 100.], [240., 100.]],
                   [[180., 120.], [240., 120.]],
                   ],
         'ball': [[400., 170., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 1],
         'spring': [[6, 7]],
         },
    # Multi-ball 10
    # 'multi_balls':
    #     {'block': [[[250., 200.], [350., 200.]],
    #                [[180., 400.], [240., 400.]],
    #                [[360., 400.], [420., 400.]]],
    #      'ball': [[300., 130., 40.],
    #               [230., 330., 40.],
    #               [370., 330., 40.]],
    #      'eli': [1, 1, 1, 0, 0, 0],
    #      'dynamic': [0, 0, 0, 1, 1, 1],
    #      },
    'stack':
        {'block': [[[180., 390.], [190., 390.]],
                   [[270., 390.], [330., 390.]],
                   [[410., 390.], [420., 390.]],
                   [[160., 300.], [270., 300.]],
                   [[290., 300.], [440., 300.]],
                   [[100., 160.], [500., 160.]]],
         'ball': [[300., 90., 60.],
                  [190., 350., 30.],
                  [410., 350., 30.],
                  [300., 350., 30.],
                  [220., 260., 30.],
                  [380., 260., 30.]],
         'eli': [0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1],
         },
    # 'multi_ball_support':
    #     {'block': [[[280., 200.], [320., 200.]],
    #                [[200., 250.], [240., 250.]],
    #                [[270., 250.], [320., 250.]],
    #                [[340., 300.], [400., 300.]],
    #                [[200., 350.], [370., 350.]],
    #                [[100., 400.], [270., 400.]],
    #                [[320., 450.], [450., 450.]],
    #                [[200., 500.], [250., 500.]]],
    #      'ball': [[300., 170., 20.],
    #               [350., 170., 20.]],
    #      'eli': [1, 1, 1, 1, 1, 1, 1, 1, 0, 0],
    #      'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
    #      },
    'multi_ball_hinder':
        {'block': [[[100., 400.], [260., 400.]],
                   [[340., 400.], [500., 400.]],
                   [[260., 300.], [260., 380.]],
                   [[340., 300.], [340., 380.]],
                   [[100., 200.], [180., 250.]],
                   [[420., 250.], [500., 200.]]],
         'ball': [[150., 200., 20.],
                  [450., 200., 20.]],
         'eli': [0, 0, 1, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1, 1],
         },
    'redirect':  # multi_ball direction
        {'block': [[[400., 400.], [500., 400.]],
                   [[500., 300.], [500., 380.]],
                   [[260., 160.], [260., 200.]],
                   [[200., 200.], [280., 250.]],
                   [[200., 400.], [370., 330.]],
                   [[340., 210.], [360., 210.]]],
         'ball': [[230., 180., 20.],
                  [350., 180., 20.]],
         'eli': [0, 0, 1, 0, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 1, 1],
         },
    'multi_ball_hole':
        {'block': [[[100., 400.], [250., 400.]],
                   [[350., 400.], [500., 400.]],
                   [[100., 300.], [100., 380.]],
                   [[500., 300.], [500., 380.]],
                   [[200., 100.], [250., 130.]],
                   [[250., 50.], [250., 100.]],
                   [[350., 120.], [400., 100.]],
                   [[350., 50.], [350., 90.]],
                   [[200., 270.], [400., 350.]],
                   ],
         'ball': [[220., 70., 20.],
                  [380., 70., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
         },
    'multi_ball_fill':
        {'block': [[[100., 420.], [460., 420.]],
                   [[100., 400.], [210., 400.]],
                   [[350., 400.], [460., 400.]],
                   [[230., 200.], [330., 200.]],
                   [[230., 180.], [330., 180.]],
                   [[100., 150.], [160., 220.]],
                   [[150., 100.], [150., 150.]],
                   [[400., 220.], [470., 150.]],
                   [[420., 100.], [420., 150.]],
                   ],
         'ball': [[120., 120., 20.],
                  [450., 120., 20.]],
         'eli': [0, 0, 0, 1, 0, 1, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1],
         },
    'lever':  # multi_ball seesaw
        {'block': [[[290., 420.], [310., 420.]],
                   [[200., 400.], [400., 400.]],
                   [[280., 200.], [320., 200.]],
                   [[380., 200.], [420., 200.]],
                   [[290., 180.], [310., 180.]],
                   [[390., 180.], [410., 180.]],
                   ],
         'ball': [[250., 370., 20.],
                  [350., 370., 20.]],
         'eli': [0, 0, 1, 1, 0, 0, 0, 0],
         'dynamic': [0, 1, 0, 0, 1, 1, 1, 1],
         },
    'multi_ball_angle':
        {'block': [[[100., 400.], [400., 400.]],
                   [[200., 350.], [210., 350.]],
                   [[200., 300.], [210., 300.]],
                   [[480., 400.], [550., 400.]],
                   [[390., 350.], [400., 350.]],
                   [[390., 300.], [400., 300.]],
                   [[100., 380.], [100., 360.]],
                   [[550., 380.], [550., 360.]],
                   [[200., 280.], [400., 280.]],
                   ],
         'ball': [[260., 250., 20.],
                  [340., 250., 20.]],
         'eli': [0, 1, 1, 0, 1, 1, 0, 0, 0, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1],
         },
    'multi_ball_pendulum':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[260., 150.], [280., 150.]],
                   [[350., 270.], [370., 270.]],
                   ],
         'ball': [[360., 170., 20.],
                  [360., 240., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
         'joint': [[6, 8], [5, 9]],
         },
    'multi_ball_spring':
        {'block': [[[10., 400.], [160., 400.]],
                   [[10., 380.], [10., 10.]],
                   [[270., 400.], [400., 400.]],
                   [[270., 380.], [270., 360.]],
                   [[350., 200.], [370., 200.]],
                   [[180., 150.], [240., 150.]],
                   [[260., 150.], [280., 150.]],
                   [[350., 270.], [370., 270.]],
                   ],
         'ball': [[360., 170., 20.],
                  [360., 240., 20.]],
         'eli': [0, 0, 0, 0, 1, 1, 1, 1, 0, 0],
         'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
         'spring': [[6, 8], [5, 9]],
         },
    'multi_ball_spring_flick':
        {'block': [[[100., 420.], [200., 420.]],
                   [[400., 400.], [590., 400.]],
                   [[10., 400.], [10., 200.]],
                   [[580., 380.], [590., 380.]],
                   [[70., 370.], [150., 370.]],
                   [[100., 150.], [180., 200.]],
                   [[170., 100.], [170., 150.]],
                   [[300., 420.], [590., 420.]],
                   ],
         'ball': [[140., 130., 20.],
                  [100., 340., 20.]],
         'eli': [0, 0, 1, 0, 1, 1, 1, 0, 0, 0],
         'dynamic': [0, 0, 0, 1, 0, 0, 0, 0, 1, 1],
         'spring': [[5, 3]],
         },
    # 'multi_ball_support_joint':
    #     {'block': [[[280., 200.], [320., 200.]],
    #                [[200., 250.], [240., 250.]],
    #                [[270., 250.], [320., 250.]],
    #                [[340., 300.], [400., 300.]],
    #                [[200., 350.], [370., 350.]],
    #                [[100., 400.], [270., 400.]],
    #                [[320., 450.], [450., 450.]],
    #                [[200., 500.], [250., 500.]]],
    #      'ball': [[300., 170., 20.],
    #               [350., 270., 20.]],
    #      'eli': [1, 1, 1, 1, 1, 1, 1, 1, 0, 0],
    #      'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
    #      'joint': [[8, 9]],
    #      },
    # 'multi_ball_support_spring':
    #     {'block': [[[280., 200.], [320., 200.]],
    #                [[200., 250.], [240., 250.]],
    #                [[270., 250.], [320., 250.]],
    #                [[340., 300.], [400., 300.]],
    #                [[200., 350.], [370., 350.]],
    #                [[100., 400.], [270., 400.]],
    #                [[320., 450.], [450., 450.]],
    #                [[200., 500.], [250., 500.]]],
    #      'ball': [[300., 170., 20.],
    #               [350., 270., 20.]],
    #      'eli': [1, 1, 1, 1, 1, 1, 1, 1, 0, 0],
    #      'dynamic': [0, 0, 0, 0, 0, 0, 0, 0, 1, 1],
    #      'spring': [[8, 9]],
    #      },
}

FOLD_LIST = ['basic', 'compositional', 'noisy', 'multi_ball']
GAMES = list(PARAS.keys())

MAX_OBJ_NUM = 0
MAX_ELI_OBJ_NUM = 0
for key in PARAS.keys():
    obj_num = len(PARAS[key]['eli'])
    if obj_num > MAX_OBJ_NUM:
        MAX_OBJ_NUM = obj_num
    eli_obj_num = sum(PARAS[key]['eli'])
    if eli_obj_num > MAX_ELI_OBJ_NUM:
        MAX_ELI_OBJ_NUM = eli_obj_num
